#!/bin/bash

# Lifeboat Report generates a status report for the desktop client
LifeboatVersion="164"

# Defaults
ApacheStatus="false"
CertbotStatus="false"
CronjobCleanup="false"
CronjobStatus="false"
Fail2banStatus="false"
FirewallStatus="false"
JailStatus="false"
LibPangoStatus="false"
LibSoupStatus="false"
LibUnwindStatus="false"
LighttpdStatus="false"
LogrotateStatus="false"
LsofStatus="false"
MariaDBStatus="false"
NginxStatus="false"
PiholeStatus="false"
PostgresStatus="false"
TreeStatus="false"
ZipStatus="false"

# Platform for library paths
ArchPlatform=$(uname -m)

# apache CentOS
if [ $(systemctl is-active httpd) = "active" ]; then
	ApacheStatus="true"

fi

# apache Ubuntu
if [ $(systemctl is-active apache2) = "active" ]; then
	ApacheStatus="true"

fi

# certbot
if [[ -e "/usr/bin/certbot" ]]; then
	CertbotStatus="true"
	
fi

# cron job
if crontab -l 2> /dev/null | grep -q ".com.strawberrysw.Lifeboat/renew.sh"; then
	CronjobStatus="true"

fi

# cron cleanup job
if [[ -e "/etc/cron.weekly/lifeboat-cleanup" ]]; then
	CronjobCleanup="true"
	
fi

# fail2ban
if [ $(systemctl is-active fail2ban) = "active" ]; then
	Fail2banStatus="true"

fi

# fail2ban jail
if [[ -e "/etc/fail2ban/jail.local" ]]; then
	JailStatus="true"
	
fi

# firewalld
if [ $(systemctl is-active firewalld) = "active" ]; then
	FirewallStatus="true"

fi

# libpango CentOS
if [[ -e "/usr/lib64/libpango-1.0.so.0" ]]; then
	LibPangoStatus="true"
	
fi

# libpango Ubuntu
if [[ -e "/usr/lib/$ArchPlatform-linux-gnu/libpango-1.0.so.0" ]]; then
	LibPangoStatus="true"
	
fi

# libsoup CentOS
if [[ -e "/usr/lib64/libsoup-2.4.so.1" ]]; then
	LibSoupStatus="true"
	
fi

# libsoup Ubuntu
if [[ -e "/usr/lib/$ArchPlatform-linux-gnu/libsoup-2.4.so.1" ]]; then
	LibSoupStatus="true"
	
fi

# libunwind CentOS
if [[ -e "/usr/lib64/libunwind.so.8" ]]; then
	LibUnwindStatus="true"
	
fi

# libunwind Ubuntu
if [[ -e "/usr/lib/$ArchPlatform-linux-gnu/libunwind.so.8" ]]; then
	LibUnwindStatus="true"
	
fi

# lighttpd
if [ $(systemctl is-active lighttpd) = "active" ]; then
	LighttpdStatus="true"

fi

# logrotate
if [ -x "$(command -v /usr/sbin/logrotate)" ]; then
	LogrotateStatus="true"
fi

# lsof CentOS
if [[ -e "/usr/sbin/lsof" ]]; then
	LsofStatus="true"
	
fi

# lsof Ubuntu
if [[ -e "/usr/bin/lsof" ]]; then
	LsofStatus="true"
	
fi

# MariaDB
if [ $(systemctl is-active mariadb) = "active" ]; then
	MariaDBStatus="true"
	
fi

# nginx
if [ $(systemctl is-active nginx) = "active" ]; then
	NginxStatus="true"

fi

# Pi-hole
if [ $(systemctl is-active pihole-FTL) = "active" ]; then
	PiholeStatus="true"

fi

# Postgres
if [ $(systemctl is-active postgresql) = "active" ]; then
	PostgresStatus="true"
	
fi

# tree
if [[ -e "/usr/bin/tree" ]]; then
	TreeStatus="true"
	
fi

# ufw
if [ $(systemctl is-active ufw) = "active" ]; then
	FirewallStatus="true"

fi

# zip
if [[ -e "/usr/bin/zip" ]]; then
	ZipStatus="true"
	
fi

echo "{"
echo "  \"LifeboatVersion\": $LifeboatVersion,"
echo "  \"ServerGUID\": \"%server_guid%\","
echo "  \"apache\": $ApacheStatus,"
echo "  \"certbot\": $CertbotStatus,"
echo "  \"croncleanup\": $CronjobCleanup,"
echo "  \"cronjob\": $CronjobStatus,"
echo "  \"fail2ban\": $Fail2banStatus,"
echo "  \"firewall\": $FirewallStatus,"
echo "  \"jail\": $JailStatus,"
echo "  \"libpango\": $LibPangoStatus,"
echo "  \"libsoup\": $LibSoupStatus,"
echo "  \"libunwind\": $LibUnwindStatus,"
echo "  \"lighttpd\": $LighttpdStatus,"
echo "  \"logrotate\": $LogrotateStatus,"
echo "  \"lsof\": $LsofStatus,"
echo "  \"mariadb\": $MariaDBStatus,"
echo "  \"nginx\": $NginxStatus,"
echo "  \"pihole\": $PiholeStatus,"
echo "  \"postgres\": $PostgresStatus,"
echo "  \"tree\": $TreeStatus,"
echo "  \"zip\": $ZipStatus"
echo "}"